@@ -84,7 +84,6 @@ public class HoTTlogReader extends HoTTbinReader {
 		HoTTbinReader.dataBlockSize = isASCII ? asciiDataBlockSize : rawDataBlockSize;
 		HoTTbinReader.buf = new byte[HoTTbinReader.dataBlockSize];
 		HoTTlogReader.rcvLogParser = (RcvLogParser) Sensor.RECEIVER.createLogParser(HoTTbinReader.pickerParameters, new int[10], timeSteps_ms, buf, numberLogChannels);
-		HoTTlogReader.chnLogParser = (ChnLogParser) Sensor.CHANNEL.createLogParser(HoTTbinReader.pickerParameters, new int[23], timeSteps_ms, buf, numberLogChannels);
 		HoTTlogReader.varLogParser = (VarLogParser) Sensor.VARIO.createLogParser(HoTTbinReader.pickerParameters, new int[13], timeSteps_ms, buf, numberLogChannels);
 		HoTTlogReader.gpsLogParser = (GpsLogParser) Sensor.GPS.createLogParser(HoTTbinReader.pickerParameters, new int[24], timeSteps_ms, buf, numberLogChannels);
 		HoTTlogReader.gamLogParser = (GamLogParser) Sensor.GAM.createLogParser(HoTTbinReader.pickerParameters, new int[26], timeSteps_ms, buf, numberLogChannels);
@@ -107,6 +106,7 @@ public class HoTTlogReader extends HoTTbinReader {
 		MenuToolBar menuToolBar = HoTTbinReader.application.getMenuToolBar();
 		int progressIndicator = (int) (numberDatablocks / 30);
 		GDE.getUiNotification().setProgress(0);
+		long sequenceNumber = 0, sequenceDelta = 0;
 
 		try {
 			HoTTbinReader.recordSets.clear();
@@ -138,6 +138,8 @@ public class HoTTlogReader extends HoTTbinReader {
 						? date + GDE.STRING_BLANK + HoTTbinReader.application.getObjectKey() : date);
 				recordSetName = recordSetNumber + GDE.STRING_RIGHT_PARENTHESIS_BLANK + HoTTAdapter.Sensor.CHANNEL.value() + recordSetNameExtend;
 				HoTTbinReader.recordSetChannel = RecordSet.createRecordSet(recordSetName, device, 6, true, true, true);
+				numberLogChannels = HoTTbinReader.recordSetChannel.size() == 23 ? 16 : numberLogChannels;
+				HoTTlogReader.chnLogParser = (ChnLogParser) Sensor.CHANNEL.createLogParser(HoTTbinReader.pickerParameters, new int[HoTTbinReader.recordSetChannel.size()], timeSteps_ms, buf, numberLogChannels);
 				channel.put(recordSetName, HoTTbinReader.recordSetChannel);
 				HoTTbinReader.recordSets.put(HoTTAdapter.Sensor.CHANNEL.value(), HoTTbinReader.recordSetChannel);
 				tmpRecordSet = channel.get(recordSetName);
@@ -158,6 +160,10 @@ public class HoTTlogReader extends HoTTbinReader {
 				if (isASCII) { //convert ASCII log data to hex
 					HoTTlogReader.convertAscii2Raw(rawDataBlockSize, HoTTbinReader.buf);
 				}
+				log.log(Level.INFO, "raw block data   " + StringHelper.byte2Hex2CharString(HoTTlogReader2.buf, 30));
+				sequenceDelta = sequenceDelta == 0 ? 1 : DataParser.getUInt32(HoTTlogReader2.buf, 0) - sequenceNumber;
+				timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms * sequenceDelta;// add default time step given by log msec
+				sequenceNumber = DataParser.getUInt32(HoTTlogReader2.buf, 0);
 				//log.logp(Level.OFF, HoTTbinReader.$CLASS_NAME, $METHOD_NAME, StringHelper.byte2Hex4CharString(HoTTbinReader.buf, rawDataBlockSize));
 				if (HoTTbinReader.buf[8] == 0 || HoTTbinReader.buf[9] == 0 || HoTTbinReader.buf[24] == 0x1F) { // tx, rx, rx sensitivity data
 					continue;
@@ -178,17 +184,19 @@ public class HoTTlogReader extends HoTTbinReader {
 					convertAscii2Raw(rawDataBlockSize, HoTTbinReader.buf);
 				}
 				
-				//if (!pickerParameters.isFilterTextModus || (HoTTbinReader.buf[6] & 0x01) == 0) { // switch into text modus
+				if (HoTTbinReader.buf[24] == 0x1F) {//rx sensitivity data
+					if (log.isLoggable(Level.INFO))
+						log.log(Level.INFO, "sensitivity data " + StringHelper.byte2Hex2CharString(HoTTlogReader2.buf, 30));
+					sequenceDelta = DataParser.getUInt32(HoTTlogReader2.buf, 0) - sequenceNumber;
+					timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms * sequenceDelta;// add default time step given by log msec
+					sequenceNumber = DataParser.getUInt32(HoTTlogReader2.buf, 0);
+					continue; //skip rx sensitivity data
+				}
+				
 				if (HoTTbinReader.buf[8] != 0 && HoTTbinReader.buf[9] != 0) { //buf 8, 9, tx,rx, rx sensitivity data
-					if (HoTTbinReader.buf[24] != 0x1F) {//rx sensitivity data
-						if (log.isLoggable(Level.INFO)) {
-							log.log(Level.INFO, String.format("Sensor %02X", HoTTbinReader.buf[26]));
-						}
-					}
-					else {
-						if (log.isLoggable(Level.INFO))
-							log.log(Level.INFO, "sensitivity data " + StringHelper.byte2Hex2CharString(HoTTbinReader.buf, HoTTbinReader.buf.length));
-						continue; //skip rx sensitivity data
+					if (log.isLoggable(Level.INFO)) {
+						//log.log(Level.INFO, String.format("Sensor %02X", HoTTbinReader.buf[26]));
+						log.log(Level.INFO, "sensor data      " + StringHelper.byte2Hex2CharString(HoTTlogReader2.buf, 30));
 					}
 
 					HoTTlogReader.rcvLogParser.trackPackageLoss(true);
@@ -200,9 +208,8 @@ public class HoTTlogReader extends HoTTbinReader {
 						}
 
 						// fill receiver data
-						if (HoTTbinReader.buf[24] != 0x1F) { //receiver sensitive data
-							HoTTlogReader.parseAddReceiver(HoTTbinReader.buf);
-						}
+						HoTTlogReader.parseAddReceiver(HoTTbinReader.buf);
+
 						if (pickerParameters.isChannelsChannelEnabled) {
 							// 0=FreCh, 1=Tx, 2=Rx, 3=Ch 1, 4=Ch 2 .. 18=Ch 16 19=PowerOff 20=BattLow 21=Reset 22=Warning
 							HoTTlogReader.parseAddChannel(HoTTbinReader.buf);
@@ -414,23 +421,29 @@ public class HoTTlogReader extends HoTTbinReader {
 								break;
 						}
 
-						timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms;// add time step from log record given in info header
+						sequenceDelta = DataParser.getUInt32(HoTTlogReader2.buf, 0) - sequenceNumber;
+						timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms * sequenceDelta;// add default time step given by log msec
+						sequenceNumber = DataParser.getUInt32(HoTTlogReader2.buf, 0);
 
 						HoTTbinReader.isJustParsed = !HoTTlogReader.rcvLogParser.updateLossStatistics();
 						
 						if (i % progressIndicator == 0)
 							GDE.getUiNotification().setProgress((int) (i * 100 / numberDatablocks));
 					}
-					else { // tx,rx == 0
+					else { // Rx == 0
 						if (HoTTlogReader.log.isLoggable(Level.FINE)) HoTTlogReader.log.log(Level.FINE, "-->> Found tx=rx=0 dBm");
 
 						HoTTlogReader.rcvLogParser.trackPackageLoss(false);
 
-						if (pickerParameters.isChannelsChannelEnabled) {
+						if (pickerParameters.isChannelsChannelEnabled && HoTTlogReader.recordSetReceiver.getRecordDataSize(true) > 0) {
+							// fill receiver data
+							HoTTlogReader.parseAddReceiverRxTxOnly(HoTTbinReader.buf);
 							HoTTlogReader.parseAddChannel(HoTTbinReader.buf);
 						}
 
-						timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms;
+						sequenceDelta = DataParser.getUInt32(HoTTlogReader2.buf, 0) - sequenceNumber;
+						timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms * sequenceDelta;// add default time step given by log msec
+						sequenceNumber = DataParser.getUInt32(HoTTlogReader2.buf, 0);
 					}
 				//} //isTextModus
 				//else if (!HoTTbinReader.isTextModusSignaled) {
@@ -594,7 +607,6 @@ public class HoTTlogReader extends HoTTbinReader {
 
 	/**
 	 * parse the buffered data from buffer and add points to record set
-	 *
 	 * @param _buf
 	 * @throws DataInconsitsentException
 	 */
@@ -603,6 +615,19 @@ public class HoTTlogReader extends HoTTbinReader {
 		HoTTlogReader.recordSetReceiver.addPoints(HoTTlogReader.rcvLogParser.getPoints(), HoTTlogReader.rcvLogParser.getTimeStep_ms());
 	}
 
+	/**
+	 * parse the buffered data from buffer and add points to record set
+	 * @param _buf
+	 * @throws DataInconsitsentException
+	 */
+	protected static void parseAddReceiverRxTxOnly(byte[] _buf) throws DataInconsitsentException {
+		int[] tmpPoints = new int[10];
+		System.arraycopy(HoTTlogReader.rcvLogParser.points, 0, tmpPoints, 0, 10);
+		HoTTlogReader.rcvLogParser.parseTxRxOnly();
+		System.arraycopy(HoTTlogReader.rcvLogParser.getPoints(), 4, tmpPoints, 4, 2); //Rx and Tx values only, keep other data since invalid
+		HoTTlogReader.recordSetReceiver.addPoints(tmpPoints, HoTTlogReader.rcvLogParser.getTimeStep_ms());
+	}
+
 	public static class RcvLogParser extends LogParser {
 		private int																	tmpVoltageRx			= 0;
 		private int																	tmpTemperatureRx	= 0;
@@ -618,6 +643,11 @@ public class HoTTlogReader extends HoTTbinReader {
 			this.buf = buffer;
 		}
 
+		protected void parseTxRxOnly() {
+			this.points[4] = buf[8] * -1000;
+			this.points[5] = buf[9] * -1000;			
+		}
+		
 		@Override
 		protected boolean parse() {
 			//log.log(Level.OFF, StringHelper.byte2Hex2CharString(buf, 12, 10));
@@ -1471,7 +1501,7 @@ public class HoTTlogReader extends HoTTbinReader {
 	}
 
 	public static class ChnLogParser extends LogParser {
-		protected final int											numberUsedChannels;
+		protected final int	numberUsedChannels;
 
 		protected ChnLogParser(PickerParameters pickerParameters, int[] points, long[] timeSteps_ms, byte[] buffer, int numberUsedChannels) {
 			super(pickerParameters, points, timeSteps_ms, buffer, Sensor.CHANNEL);
@@ -1482,12 +1512,12 @@ public class HoTTlogReader extends HoTTbinReader {
 		@Override
 		protected boolean parse() {
 
-			//0=FreCh, 1=Tx, 2=Rx, 3=Ch 1, 4=Ch 2 .. 18=Ch 16 19=PowerOff 20=BattLow 21=Reset 22=Warning
+			//0=FreCh, 1=Tx, 2=Rx, 3=Ch01, 4=Ch02 .. 18=Ch16 19=Ch17 .. 34=Ch32
 			this.points[0] = buf[7] * -1000;
 			this.points[1] = buf[8] * -1000;
 			this.points[2] = buf[9] * -1000;
 
-			for (int i = 0,j = 0; i < numberUsedChannels && i < 16; i++,j+=2) {
+			for (int i = 0,j = 0; i < numberUsedChannels; i++,j+=2) {
 				this.points[i + 3] = (DataParser.parse2UnsignedShort(buf, (66 + j)) / 2) * 1000;
 			}
 			//Ph(D)[4], Evt1(H)[5], Evt2(D)[6], Fch(D)[7], TXdBm(-D)[8], RXdBm(-D)[9], RfRcvRatio(D)[10], TrnRcvRatio(D)[11]
