@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with GNU DataExplorer.  If not, see <https://www.gnu.org/licenses/>.
 
-    Copyright (c) 2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023 Winfried Bruegmann
+    Copyright (c) 2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Winfried Bruegmann
 ****************************************************************************************/
 package gde.device.graupner;
 
@@ -66,9 +66,9 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 		long startTime = System.nanoTime() / 1000000;
 		FileInputStream file_input = new FileInputStream(file);
 		DataInputStream data_in = new DataInputStream(file_input);
-		HoTTAdapter2 device = (HoTTAdapter2) HoTTbinReader.application.getActiveDevice();
+		HoTTAdapter2 device = (HoTTAdapter2) HoTTlogReaderD.application.getActiveDevice();
 		HoTTlogReaderD.isHoTTAdapter2 = HoTTlogReaderD.application.getActiveDevice() instanceof HoTTAdapter2;
-		int recordSetNumber = HoTTbinReader.channels.get(1).maxSize() + 1;
+		int recordSetNumber = HoTTlogReaderD.channels.get(1).maxSize() + 1;
 		String recordSetName = GDE.STRING_EMPTY;
 		String recordSetNameExtend = getRecordSetExtend(file);
 		Channel channel = null;
@@ -90,12 +90,29 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 		// 57=LowestCellNumber, 58=Pressure, 59=Event G
 		// 60=Voltage E, 61=Current E, 62=Capacity E, 63=Power E, 64=Balance E, 65=CellVoltage E1, 66=CellVoltage E2 .... 78=CellVoltage E14,
 		// 79=Voltage E1, 80=Voltage E2, 81=Temperature E1, 82=Temperature E2 83=Revolution E 84=MotorTime 85=Speed 86=Event E
-		// 87=Ch 1, 88=Ch 2, 89=Ch 3 .. 102=Ch 16, 103=PowerOff, 104=BatterieLow, 105=Reset, 106=reserve
-		// 107=VoltageM, 108=CurrentM, 109=CapacityM, 110=PowerM, 111=RevolutionM, 112=TemperatureM 1, 113=TemperatureM 2 114=Voltage_min, 115=Current_max,
-		// 116=Revolution_max, 117=Temperature1_max, 118=Temperature2_max 119=Event M
-		// 120=Speed 121=Speed_max 122=PWM 123=Throttle 124=VoltageBEC 125=VoltageBEC_min 125=CurrentBEC 127=TemperatureBEC 128=TemperatureCap 
-		// 129=Timing(empty) 130=Temperature_aux 131=Gear 132=YGEGenExt 133=MotStatEscNr 134=misc ESC_15 135=VersionESC
-		// 136=Test 00 137=Test 01.. 149=Test 12
+		// 87=Ch 1, 88=Ch 2, 89=Ch 3 .. 102=Ch 16, 103=Ch17 ... 118=Ch32, 119=PowerOff, 120=BatterieLow, 121=Reset, 122=reserve
+		// ESC1
+		// 123=VoltageM, 124=CurrentM, 125=CapacityM, 126=PowerM, 127=RevolutionM, 128=TemperatureM 1, 129=TemperatureM 2 130=Voltage_min, 131=Current_max,
+		// 132=Revolution_max, 133=Temperature1_max, 134=Temperature2_max 135=Event M
+		// 136=Speed 137=Speed_max 138=PWM 139=Throttle 140=VoltageBEC 141=VoltageBEC_max 142=CurrentBEC 143=TemperatureBEC 144=TemperatureCap 
+		// 145=Timing(empty) 146=Temperature_aux 147=Gear 148=YGEGenExt 149=MotStatEscNr 150=misc ESC_15 151=VersionESC
+		//ESC2
+		// 152=VoltageM, 153=CurrentM, 154=CapacityM, 155=PowerM, 156=RevolutionM, 157=TemperatureM 1, 158=TemperatureM 2 159=Voltage_min, 160=Current_max,
+		// 161=Revolution_max, 162=Temperature1_max, 163=Temperature2_max 164=Event M
+		// 165=Speed 166=Speed_max 167=PWM 168=Throttle 169=VoltageBEC 170=VoltageBEC_min 171=CurrentBEC 172=TemperatureBEC 173=TemperatureCap 
+		// 174=Timing(empty) 175=Temperature_aux 176=Gear 177=YGEGenExt 178=MotStatEscNr 179=misc ESC_15 180=VersionESC
+		//ESC3
+		// 181=VoltageM2, 182=CurrentM, 183=CapacityM, 184=PowerM, 185=RevolutionM, 186=TemperatureM 1, 187=TemperatureM 2 188=Voltage_min, 189=Current_max,
+		// 190=Revolution_max, 191=Temperature1_max, 192=Temperature2_max 193=Event M
+		// 194=Speed 195=Speed_max 196=PWM 197=Throttle 198=VoltageBEC 199=VoltageBEC_min 200=CurrentBEC 201=TemperatureBEC 202=TemperatureCap 
+		// 203=Timing(empty) 204=Temperature_aux 205=Gear 206=YGEGenExt 207=MotStatEscNr 208=misc ESC_15 209=VersionESC
+		//ESC4
+		// 210=VoltageM3, 211=CurrentM, 212=CapacityM, 213=PowerM, 214=RevolutionM, 215=TemperatureM 1, 216=TemperatureM 2 217=Voltage_min, 218=Current_max,
+		// 219=Revolution_max, 220=Temperature1_max, 221=Temperature2_max 222=Event M
+		// 223=Speed 224=Speed_max 225=PWM 226=Throttle 227=VoltageBEC 228=VoltageBEC_min 229=CurrentBEC 230=TemperatureBEC 231=TemperatureCap 
+		// 232=Timing(empty) 233=Temperature_aux 234=Gear 235=YGEGenExt 236=MotStatEscNr 237=misc ESC_15 238=VersionESC
+
+		// 239=Test 00 240=Test 01.. 251=Test 12
 		HoTTlogReaderD.points = new int[device.getNumberOfMeasurements(channelNumber)];
 		long[] timeSteps_ms = new long[] {0};
 		int numberLogChannels = Integer.valueOf(fileInfoHeader.get("LOG NOB CHANNEL"));
@@ -103,7 +120,7 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 		int rawDataBlockSize = Integer.parseInt(fileInfoHeader.get(HoTTAdapter.RAW_LOG_SIZE));
 		int asciiDataBlockSize = Integer.parseInt(fileInfoHeader.get(HoTTAdapter.ASCII_LOG_SIZE));
     int[] valuesRec = new int[10];
-    int[] valuesChn = new int[23];
+    int[] valuesChn = new int[39];
     int[] valuesVar = new int[27];
     int[] valuesGPS = new int[24];
     int[] valuesGAM = new int[26];
@@ -113,36 +130,36 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
     int[] valuesESC3 = new int[30];
     int[] valuesESC4 = new int[30];
 		HoTTlogReaderD.dataBlockSize = isASCII ? asciiDataBlockSize : rawDataBlockSize;
-		HoTTlogReaderD.buf = new byte[HoTTbinReader.dataBlockSize];
-		HoTTlogReaderD.rcvLogParser = (RcvLogParser) Sensor.RECEIVER.createLogParser(HoTTbinReader.pickerParameters, valuesRec, timeSteps_ms, buf, numberLogChannels);
-		HoTTlogReaderD.chnLogParser = (ChnLogParser) Sensor.CHANNEL.createLogParser(HoTTbinReader.pickerParameters, valuesChn, timeSteps_ms, buf, numberLogChannels);
-		HoTTlogReaderD.varLogParser = (VarLogParserD) Sensor.VARIO.createLogParserD(HoTTbinReader.pickerParameters, valuesVar, timeSteps_ms, buf, numberLogChannels);
-		HoTTlogReaderD.gpsLogParser = (GpsLogParser) Sensor.GPS.createLogParser(HoTTbinReader.pickerParameters, valuesGPS, timeSteps_ms, buf, numberLogChannels);
-		HoTTlogReaderD.gamLogParser = (GamLogParser) Sensor.GAM.createLogParser(HoTTbinReader.pickerParameters, valuesGAM, timeSteps_ms, buf, numberLogChannels);
-		HoTTlogReaderD.eamLogParser = (EamLogParser) Sensor.EAM.createLogParser(HoTTbinReader.pickerParameters, valuesEAM, timeSteps_ms, buf, numberLogChannels);
-		HoTTlogReaderD.escLogParser = (EscLogParser) Sensor.ESC.createLogParser(HoTTbinReader.pickerParameters, valuesESC, timeSteps_ms, buf, numberLogChannels);
-		HoTTlogReaderD.esc2LogParser = (EscLogParser) Sensor.ESC2.createLogParser(HoTTbinReader.pickerParameters, valuesESC2, timeSteps_ms, buf, numberLogChannels);
-		HoTTlogReaderD.esc3LogParser = (EscLogParser) Sensor.ESC3.createLogParser(HoTTbinReader.pickerParameters, valuesESC3, timeSteps_ms, buf, numberLogChannels);
-		HoTTlogReaderD.esc4LogParser = (EscLogParser) Sensor.ESC4.createLogParser(HoTTbinReader.pickerParameters, valuesESC4, timeSteps_ms, buf, numberLogChannels);
+		HoTTlogReaderD.buf = new byte[HoTTlogReaderD.dataBlockSize];
+		HoTTlogReaderD.rcvLogParser = (RcvLogParser) Sensor.RECEIVER.createLogParser(HoTTlogReaderD.pickerParameters, valuesRec, timeSteps_ms, buf, numberLogChannels);
+		HoTTlogReaderD.chnLogParser = (ChnLogParser) Sensor.CHANNEL.createLogParser(HoTTlogReaderD.pickerParameters, valuesChn, timeSteps_ms, buf, numberLogChannels);
+		HoTTlogReaderD.varLogParser = (VarLogParserD) Sensor.VARIO.createLogParserD(HoTTlogReaderD.pickerParameters, valuesVar, timeSteps_ms, buf, numberLogChannels);
+		HoTTlogReaderD.gpsLogParser = (GpsLogParser) Sensor.GPS.createLogParser(HoTTlogReaderD.pickerParameters, valuesGPS, timeSteps_ms, buf, numberLogChannels);
+		HoTTlogReaderD.gamLogParser = (GamLogParser) Sensor.GAM.createLogParser(HoTTlogReaderD.pickerParameters, valuesGAM, timeSteps_ms, buf, numberLogChannels);
+		HoTTlogReaderD.eamLogParser = (EamLogParser) Sensor.EAM.createLogParser(HoTTlogReaderD.pickerParameters, valuesEAM, timeSteps_ms, buf, numberLogChannels);
+		HoTTlogReaderD.escLogParser = (EscLogParser) Sensor.ESC.createLogParser(HoTTlogReaderD.pickerParameters, valuesESC, timeSteps_ms, buf, numberLogChannels);
+		HoTTlogReaderD.esc2LogParser = (EscLogParser) Sensor.ESC2.createLogParser(HoTTlogReaderD.pickerParameters, valuesESC2, timeSteps_ms, buf, numberLogChannels);
+		HoTTlogReaderD.esc3LogParser = (EscLogParser) Sensor.ESC3.createLogParser(HoTTlogReaderD.pickerParameters, valuesESC3, timeSteps_ms, buf, numberLogChannels);
+		HoTTlogReaderD.esc4LogParser = (EscLogParser) Sensor.ESC4.createLogParser(HoTTlogReaderD.pickerParameters, valuesESC4, timeSteps_ms, buf, numberLogChannels);
 		int logTimeStep_ms = 1000/Integer.valueOf(fileInfoHeader.get("COUNTER").split("/")[1].split(GDE.STRING_BLANK)[0]);
 		boolean isVarioDetected = false;
 		boolean isGPSdetected = false;
 		boolean isESCdetected = false, isESC2detected = false, isESC3detected = false, isESC4detected = false;
 		int logDataOffset = Integer.valueOf(fileInfoHeader.get("LOG DATA OFFSET"));
 		long numberDatablocks = Long.parseLong(fileInfoHeader.get(HoTTAdapter.LOG_COUNT));
-		long startTimeStamp_ms = HoTTbinReader.getStartTimeStamp(fileInfoHeader.get("LOG START TIME"), HoTTbinReader.getStartTimeStamp(file.getName(), file.lastModified(), numberDatablocks));
+		long startTimeStamp_ms = HoTTlogReaderD.getStartTimeStamp(fileInfoHeader.get("LOG START TIME"), HoTTlogReaderD.getStartTimeStamp(file.getName(), file.lastModified(), numberDatablocks));
 		String date = new SimpleDateFormat("yyyy-MM-dd").format(startTimeStamp_ms); //$NON-NLS-1$
 		String dateTime = new SimpleDateFormat("yyyy-MM-dd, HH:mm:ss").format(startTimeStamp_ms); //$NON-NLS-1$
 		RecordSet tmpRecordSet;
-		MenuToolBar menuToolBar = HoTTbinReader.application.getMenuToolBar();
+		MenuToolBar menuToolBar = HoTTlogReaderD.application.getMenuToolBar();
 		int progressIndicator = (int) (numberDatablocks / 30);
 		GDE.getUiNotification().setProgress(0);
 
 		try {
 			//receiver data are always contained
-			channel = HoTTbinReader.channels.get(channelNumber);
-			String newFileDescription = HoTTbinReader.application.isObjectoriented() ? date + GDE.STRING_BLANK + HoTTbinReader.application.getObjectKey()	: date;
-			if (channel.getFileDescription().length() <= newFileDescription.length() || (HoTTbinReader.application.isObjectoriented() && !channel.getFileDescription().contains(HoTTbinReader.application.getObjectKey())))
+			channel = HoTTlogReaderD.channels.get(channelNumber);
+			String newFileDescription = HoTTlogReaderD.application.isObjectoriented() ? date + GDE.STRING_BLANK + HoTTlogReaderD.application.getObjectKey()	: date;
+			if (channel.getFileDescription().length() <= newFileDescription.length() || (HoTTlogReaderD.application.isObjectoriented() && !channel.getFileDescription().contains(HoTTlogReaderD.application.getObjectKey())))
 				channel.setFileDescription(newFileDescription);
 			recordSetName = recordSetNumber + device.getRecordSetStemNameReplacement() + recordSetNameExtend;
 			HoTTlogReaderD.recordSet = RecordSet.createRecordSet(recordSetName, device, channelNumber, true, true, true);
@@ -150,73 +167,80 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 			tmpRecordSet = channel.get(recordSetName);
 			tmpRecordSet.setRecordSetDescription(device.getName() + GDE.STRING_MESSAGE_CONCAT + Messages.getString(MessageIds.GDE_MSGT0129) + dateTime);
 			tmpRecordSet.setStartTimeStamp(startTimeStamp_ms);
+			long sequenceNumber = 0, sequenceDelta = 0;
 			//recordSet initialized and ready to add data
 
+			log.log(Level.INFO, fileInfoHeader.toString());
 			//read all the data blocks from the file and parse
 			data_in.skip(logDataOffset);
 			int i = 0;
 			for (; i < numberDatablocks; i++) { //skip log entries before transmitter active
-				data_in.read(HoTTbinReader.buf);
+				data_in.read(HoTTlogReaderD.buf);
 				if (isASCII) { //convert ASCII log data to hex
-					HoTTlogReader.convertAscii2Raw(rawDataBlockSize, HoTTbinReader.buf);
+					HoTTlogReader.convertAscii2Raw(rawDataBlockSize, HoTTlogReaderD.buf);
 				}
-				//log.logp(Level.OFF, HoTTbinReader.$CLASS_NAME, $METHOD_NAME, StringHelper.byte2Hex4CharString(HoTTbinReader.buf, rawDataBlockSize));
-				if (HoTTbinReader.buf[8] == 0 || HoTTbinReader.buf[9] == 0 || HoTTbinReader.buf[24] == 0x1F) { // tx, rx, rx sensitivity data
+				//log.logp(Level.OFF, HoTTlogReaderD.$CLASS_NAME, $METHOD_NAME, StringHelper.byte2Hex4CharString(HoTTlogReaderD.buf, rawDataBlockSize));
+				log.log(Level.INFO, "raw block data   " + StringHelper.byte2Hex2CharString(HoTTlogReaderD.buf, 30));
+				sequenceDelta = sequenceDelta == 0 ? 1 : DataParser.getUInt32(HoTTlogReaderD.buf, 0) - sequenceNumber;
+				timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms * sequenceDelta;// add default time step given by log msec
+				sequenceNumber = DataParser.getUInt32(HoTTlogReaderD.buf, 0);
+
+				if (HoTTlogReaderD.buf[8] == 0 || HoTTlogReaderD.buf[9] == 0 || HoTTlogReaderD.buf[24] == 0x1F) { // tx, rx, rx sensitivity data
 					continue;
 				}
 				break;
 			}
 			
 			for (; i < numberDatablocks; i++) {
-				data_in.read(HoTTbinReader.buf);
+				data_in.read(HoTTlogReaderD.buf);
 				if (log.isLoggable(Level.FINE)) {
 					if (isASCII)
-						log.logp(Level.FINE, HoTTbinReader.$CLASS_NAME, $METHOD_NAME, new String(HoTTbinReader.buf));
+						log.logp(Level.FINE, HoTTlogReaderD.$CLASS_NAME, $METHOD_NAME, new String(HoTTlogReaderD.buf));
 					else
-						log.logp(Level.FINE, HoTTbinReader.$CLASS_NAME, $METHOD_NAME, StringHelper.byte2Hex4CharString(HoTTbinReader.buf, HoTTbinReader.buf.length));
+						log.logp(Level.FINE, HoTTlogReaderD.$CLASS_NAME, $METHOD_NAME, StringHelper.byte2Hex4CharString(HoTTlogReaderD.buf, HoTTlogReaderD.buf.length));
 				}
 
 				if (isASCII) { //convert ASCII log data to hex
-					HoTTlogReader.convertAscii2Raw(rawDataBlockSize, HoTTbinReader.buf);
+					HoTTlogReader.convertAscii2Raw(rawDataBlockSize, HoTTlogReaderD.buf);
 				}
 
 				//Ph(D)[4], Evt1(H)[5], Evt2(D)[6], Fch(D)[7], TXdBm(-D)[8], RXdBm(-D)[9], RfRcvRatio(D)[10], TrnRcvRatio(D)[11]
 				//STATUS : Ph(D)[4], Evt1(H)[5], Evt2(D)[6], Fch(D)[7], TXdBm(-D)[8], RXdBm(-D)[9], RfRcvRatio(D)[10], TrnRcvRatio(D)[11]
 				//S.INFOR : DEV(D)[22], CH(D)[23], SID(H)[24], WARN(H)[25]
-				//if (!HoTTAdapter.isFilterTextModus || (HoTTbinReader.buf[6] & 0x01) == 0) { //switch into text modus
-				if (HoTTbinReader.buf[8] != 0 && HoTTbinReader.buf[9] != 0) { //buf 8, 9, tx,rx, rx sensitivity data
-					if (HoTTbinReader.buf[24] != 0x1F) {//rx sensitivity data
-						if (log.isLoggable(Level.INFO)) {
-							log.log(Level.INFO, String.format("Sensor %02X", HoTTbinReader.buf[26]));
-						}
-					}
-					else {
-						if (log.isLoggable(Level.INFO))
-							log.log(Level.INFO, "sensitivity data " + StringHelper.byte2Hex2CharString(HoTTbinReader.buf, HoTTbinReader.buf.length));
-						continue; //skip rx sensitivity data
+				//if (!HoTTAdapter.isFilterTextModus || (HoTTlogReaderD.buf[6] & 0x01) == 0) { //switch into text modus
+				if (HoTTlogReaderD.buf[24] == 0x1F) {//rx sensitivity data
+					if (log.isLoggable(Level.INFO))
+						log.log(Level.INFO, "sensitivity data " + StringHelper.byte2Hex2CharString(HoTTlogReaderD.buf, HoTTlogReaderD.buf.length));
+					sequenceDelta = DataParser.getUInt32(HoTTlogReaderD.buf, 0) - sequenceNumber;
+					timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms * sequenceDelta;// add default time step given by log msec
+					sequenceNumber = DataParser.getUInt32(HoTTlogReaderD.buf, 0);
+					continue; //skip rx sensitivity data
+				}
+				
+				if (HoTTlogReaderD.buf[8] != 0 && HoTTlogReaderD.buf[9] != 0) { //buf 8, 9, tx,rx, rx sensitivity data
+					if (log.isLoggable(Level.INFO)) {
+						log.log(Level.INFO, "sensor data      " + StringHelper.byte2Hex2CharString(HoTTlogReaderD.buf, HoTTlogReaderD.buf.length));
 					}
 						
 					HoTTlogReaderD.rcvLogParser.trackPackageLoss(true);
 
 					//create and fill sensor specific data record sets
 					if (log.isLoggable(Level.FINEST)) {
-						log.logp(Level.FINEST, HoTTbinReader.$CLASS_NAME, $METHOD_NAME,
-								StringHelper.byte2Hex2CharString(new byte[] { HoTTbinReader.buf[7] }, 1) + GDE.STRING_MESSAGE_CONCAT + StringHelper.printBinary(HoTTbinReader.buf[7], false));
+						log.logp(Level.FINEST, HoTTlogReaderD.$CLASS_NAME, $METHOD_NAME,
+								StringHelper.byte2Hex2CharString(new byte[] { HoTTlogReaderD.buf[7] }, 1) + GDE.STRING_MESSAGE_CONCAT + StringHelper.printBinary(HoTTlogReaderD.buf[7], false));
 					}
 
 					//fill receiver data
-					if (HoTTbinReader.buf[24] != 0x1F) { //receiver sensitive data
-						//in 0=RX-TX-VPacks, 1=RXSQ, 2=Strength, 3=VPacks, 4=Tx, 5=Rx, 6=VoltageRx, 7=TemperatureRx 8=VoltageRxMin 9=EventRx
-						isReceiverData = HoTTlogReaderD.rcvLogParser.parse();
-						System.arraycopy(valuesRec, 0, HoTTlogReaderD.points, 0, 10); //migrate/copy receiver points
-					}
+					//in 0=RX-TX-VPacks, 1=RXSQ, 2=Strength, 3=VPacks, 4=Tx, 5=Rx, 6=VoltageRx, 7=TemperatureRx 8=VoltageRxMin 9=EventRx
+					isReceiverData = HoTTlogReaderD.rcvLogParser.parse();
+					System.arraycopy(valuesRec, 0, HoTTlogReaderD.points, 0, 10); //migrate/copy receiver points
 
 					HoTTlogReaderD.chnLogParser.parse();
 					//in 0=FreCh, 1=Tx, 2=Rx, 3=Ch 1, 4=Ch 2 .. 18=Ch 16 19=PowerOff 20=BattLow 21=Reset 22=Warning
 					//out 87=Ch 1, 88=Ch 2, 89=Ch 3 .. 102=Ch 16, 103=PowerOff, 104=BatterieLow, 105=Reset, 106=reserv
-					System.arraycopy(valuesChn, 3, HoTTlogReaderD.points, 87, 20); //copy channel data and events, warning
+					System.arraycopy(valuesChn, 3, HoTTlogReaderD.points, 87, 36); //copy channel data and events, warning
 
-					switch ((byte) (HoTTbinReader.buf[26] & 0xFF)) { //actual sensor
+					switch ((byte) (HoTTlogReaderD.buf[26] & 0xFF)) { //actual sensor
 					case HoTTAdapter.ANSWER_SENSOR_VARIO_19200:
 						isVarioData = HoTTlogReaderD.varLogParser.parse();
 						if (isVarioData && isReceiverData) {
@@ -224,7 +248,7 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 							isReceiverData = false;
 
 							if (!isVarioDetected) {
-								HoTTAdapter2.updateVarioTypeDependent((HoTTbinReader.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet);
+								HoTTAdapter2.updateVarioTypeDependent((HoTTlogReaderD.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet);
 								isVarioDetected = true;
 							}
 						}
@@ -236,7 +260,7 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 							isReceiverData = false;
 
 							if (!isGPSdetected) {
-								HoTTAdapter2.updateGpsTypeDependent((HoTTbinReader.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet, 0);
+								HoTTAdapter2.updateGpsTypeDependent((HoTTlogReaderD.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet, 0);
 								isGPSdetected = true;
 							}
 						}
@@ -262,7 +286,7 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 							isReceiverData = false;
 
 							if (!isESCdetected) {
-								HoTTAdapterD.updateEscTypeDependent((HoTTbinReader.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet, 1);
+								HoTTAdapterD.updateEscTypeDependent((HoTTlogReaderD.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet, 1);
 								isESCdetected = true;
 							}
 						}
@@ -275,7 +299,7 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 							isReceiverData = false;
 
 							if (!isESC2detected) {
-								HoTTAdapterD.updateEscTypeDependent((HoTTbinReader.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet, 2);
+								HoTTAdapterD.updateEscTypeDependent((HoTTlogReaderD.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet, 2);
 								HoTTlogReaderD.detectedSensors.add(Sensor.ESC2);
 								isESC2detected = true;
 							}
@@ -289,7 +313,7 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 							isReceiverData = false;
 
 							if (!isESC3detected) {
-								HoTTAdapterD.updateEscTypeDependent((HoTTbinReader.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet, 3);
+								HoTTAdapterD.updateEscTypeDependent((HoTTlogReaderD.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet, 3);
 								HoTTlogReaderD.detectedSensors.add(Sensor.ESC3);
 								isESC3detected = true;
 							}
@@ -303,7 +327,7 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 							isReceiverData = false;
 
 							if (!isESC4detected) {
-								HoTTAdapterD.updateEscTypeDependent((HoTTbinReader.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet, 4);
+								HoTTAdapterD.updateEscTypeDependent((HoTTlogReaderD.buf[65] & 0xFF), device, HoTTlogReaderD.recordSet, 4);
 								HoTTlogReaderD.detectedSensors.add(Sensor.ESC4);
 								isESC4detected = true;
 							}
@@ -322,7 +346,9 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 						HoTTlogReaderD.recordSet.addPoints(HoTTlogReaderD.points, HoTTlogReaderD.chnLogParser.getTimeStep_ms());
 					}
 
-					timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms;// add default time step given by log msec
+					sequenceDelta = DataParser.getUInt32(HoTTlogReaderD.buf, 0) - sequenceNumber;
+					timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms * sequenceDelta;// add default time step given by log msec
+					sequenceNumber = DataParser.getUInt32(HoTTlogReaderD.buf, 0);
 
 					HoTTlogReaderD.isJustMigrated = !HoTTlogReaderD.rcvLogParser.updateLossStatistics();
 					HoTTlogReaderD.isJustMigrated = false;
@@ -330,16 +356,24 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 					if (i % progressIndicator == 0) GDE.getUiNotification().setProgress((int) (i * 100 / numberDatablocks));
 				}
 				else { //skip empty block, but add time step
-					if (log.isLoggable(Level.FINE)) log.log(Level.FINE, "-->> Found tx=rx=0 dBm");
+					if (log.isLoggable(Level.FINE)) log.log(Level.FINE, "-->> Found rx=0 dBm");
+					if (log.isLoggable(Level.INFO)) {
+						log.log(Level.INFO, "sensor data Tx=Rx=0 " + StringHelper.byte2Hex2CharString(HoTTlogReaderD.buf, HoTTlogReaderD.buf.length));
+					}
 
 					HoTTlogReaderD.rcvLogParser.trackPackageLoss(false);
+					//fill receiver data
+					isReceiverData = HoTTlogReaderD.rcvLogParser.parse();
+					System.arraycopy(valuesRec, 4, HoTTlogReaderD.points, 4, 2); //Rx and Tx values only, keep other data since invalid
 
 					HoTTlogReaderD.chnLogParser.parse();
-					//in 0=FreCh, 1=Tx, 2=Rx, 3=Ch 1, 4=Ch 2 .. 18=Ch 16 19=PowerOff 20=BattLow 21=Reset 22=Warning
 					System.arraycopy(valuesChn, 3, HoTTlogReaderD.points, 87, 20); //copy channel data and events, warning
+					
 					HoTTlogReaderD.recordSet.addPoints(HoTTlogReaderD.points, HoTTlogReaderD.chnLogParser.getTimeStep_ms());
 
-					timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms;
+					sequenceDelta = DataParser.getUInt32(HoTTlogReaderD.buf, 0) - sequenceNumber;
+					timeSteps_ms[BinParser.TIMESTEP_INDEX] += logTimeStep_ms * sequenceDelta;// add default time step given by log msec
+					sequenceNumber = DataParser.getUInt32(HoTTlogReaderD.buf, 0);
 				}
 			}
 			Sensor altitudeClimbSensorSelection = pickerParameters.altitudeClimbSensorSelection == 0 ? null : Sensor.fromOrdinal(pickerParameters.altitudeClimbSensorSelection);
@@ -357,15 +391,15 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 			String packageLossPercentage = tmpRecordSet.getRecordDataSize(true) > 0 
 					? String.format("%.1f", HoTTlogReaderD.rcvLogParser.getLostPackages().percentage) 
 					: "100";
-			HoTTbinReader.detectedSensors.add(Sensor.CHANNEL);
+			HoTTlogReaderD.detectedSensors.add(Sensor.CHANNEL);
 			tmpRecordSet.setRecordSetDescription(tmpRecordSet.getRecordSetDescription()
 					+ Messages.getString(gde.device.graupner.hott.MessageIds.GDE_MSGI2404, new Object[] { HoTTlogReaderD.rcvLogParser.getLossTotal(), HoTTlogReader.rcvLogParser.getLostPackages().lossTotal, packageLossPercentage, HoTTlogReader.rcvLogParser.getLostPackages().getStatistics() })
 					+ String.format(" - Sensor: %s", HoTTlogReaderD.detectedSensors.toString())
 					+ (altitudeClimbSensorSelection != null && (detectedSensors.contains(Sensor.fromOrdinal(pickerParameters.altitudeClimbSensorSelection)) || detectedSensors.contains(altitudeClimbSensorSelection))
 							? String.format(" - %s = %s", Messages.getString(gde.device.graupner.hott.MessageIds.GDE_MSGT2419), altitudeClimbSensorSelection)
 							: ""));
-			log.logp(Level.WARNING, HoTTbinReader.$CLASS_NAME, $METHOD_NAME, "skipped number receiver data due to package loss = " + HoTTlogReaderD.rcvLogParser.getLostPackages().lossTotal); //$NON-NLS-1$
-			log.logp(Level.TIME, HoTTbinReader.$CLASS_NAME, $METHOD_NAME, "read time = " + StringHelper.getFormatedTime("mm:ss:SSS", (System.nanoTime() / 1000000 - startTime))); //$NON-NLS-1$ //$NON-NLS-2$
+			log.logp(Level.WARNING, HoTTlogReaderD.$CLASS_NAME, $METHOD_NAME, "skipped number receiver data due to package loss = " + HoTTlogReaderD.rcvLogParser.getLostPackages().lossTotal); //$NON-NLS-1$
+			log.logp(Level.TIME, HoTTlogReaderD.$CLASS_NAME, $METHOD_NAME, "read time = " + StringHelper.getFormatedTime("mm:ss:SSS", (System.nanoTime() / 1000000 - startTime))); //$NON-NLS-1$ //$NON-NLS-2$
 
 			if (GDE.isWithUi()) {
 				GDE.getUiNotification().setProgress(99);
@@ -398,7 +432,7 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 			super.parse();
 
 			//if ((_buf[40] & 0xFF) == 0xFF) { // gyro receiver
-			// 223=Test 00 224=Test 01.. 235=Test 12
+			// 239=Test 00 240=Test 01.. 251=Test 12
 				for (int i = 0, j = 0; i < 13; i++, j += 2) {
 					this.points[i + 14] = DataParser.parse2Short(buf, 40 + j) * 1000;
 				}
@@ -434,28 +468,29 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 		// 57=LowestCellNumber, 58=Pressure, 59=Event G
 		// 60=Voltage E, 61=Current E, 62=Capacity E, 63=Power E, 64=Balance E, 65=CellVoltage E1, 66=CellVoltage E2 .... 78=CellVoltage E14,
 		// 79=Voltage E1, 80=Voltage E2, 81=Temperature E1, 82=Temperature E2 83=Revolution E 84=MotorTime 85=Speed 86=Event E
-		// 87=Ch 1, 88=Ch 2, 89=Ch 3 .. 102=Ch 16, 103=PowerOff, 104=BatterieLow, 105=Reset, 106=reserve
-		// 107=VoltageM, 108=CurrentM, 109=CapacityM, 110=PowerM, 111=RevolutionM, 112=TemperatureM 1, 113=TemperatureM 2 114=Voltage_min, 115=Current_max,
-		// 116=Revolution_max, 117=Temperature1_max, 118=Temperature2_max 119=Event M
-		// 120=Speed 121=Speed_max 122=PWM 123=Throttle 124=VoltageBEC 125=VoltageBEC_min 125=CurrentBEC 127=TemperatureBEC 128=TemperatureCap 
-		// 129=Timing(empty) 130=Temperature_aux 131=Gear 132=YGEGenExt 133=MotStatEscNr 134=misc ESC_15 135=VersionESC
+		// 87=Ch 1, 88=Ch 2, 89=Ch 3 .. 102=Ch 16, 103=Ch17 ... 118=Ch32, 119=PowerOff, 120=BatterieLow, 121=Reset, 122=reserve
+		//ESC1
+		// 123=VoltageM, 124=CurrentM, 125=CapacityM, 126=PowerM, 127=RevolutionM, 128=TemperatureM 1, 129=TemperatureM 2 130=Voltage_min, 131=Current_max,
+		// 132=Revolution_max, 133=Temperature1_max, 134=Temperature2_max 135=Event M
+		// 136=Speed 137=Speed_max 138=PWM 139=Throttle 140=VoltageBEC 141=VoltageBEC_max 142=CurrentBEC 143=TemperatureBEC 144=TemperatureCap 
+		// 145=Timing(empty) 146=Temperature_aux 147=Gear 148=YGEGenExt 149=MotStatEscNr 150=misc ESC_15 151=VersionESC
 		//ESC2
-		// 136=VoltageM, 137=CurrentM, 138=CapacityM, 139=PowerM, 140=RevolutionM, 141=TemperatureM 1, 142=TemperatureM 2 143=Voltage_min, 144=Current_max,
-		// 145=Revolution_max, 146=Temperature1_max, 147=Temperature2_max 148=Event M
-		// 149=Speed 150=Speed_max 151=PWM 152=Throttle 153=VoltageBEC 154=VoltageBEC_min 155=CurrentBEC 156=TemperatureBEC 157=TemperatureCap 
-		// 158=Timing(empty) 159=Temperature_aux 160=Gear 161=YGEGenExt 162=MotStatEscNr 163=misc ESC_15 164=VersionESC
+		// 152=VoltageM, 153=CurrentM, 154=CapacityM, 155=PowerM, 156=RevolutionM, 157=TemperatureM 1, 158=TemperatureM 2 159=Voltage_min, 160=Current_max,
+		// 161=Revolution_max, 162=Temperature1_max, 163=Temperature2_max 164=Event M
+		// 165=Speed 166=Speed_max 167=PWM 168=Throttle 169=VoltageBEC 170=VoltageBEC_min 171=CurrentBEC 172=TemperatureBEC 173=TemperatureCap 
+		// 174=Timing(empty) 175=Temperature_aux 176=Gear 177=YGEGenExt 178=MotStatEscNr 179=misc ESC_15 180=VersionESC
 		//ESC3
-		// 165=VoltageM2, 166=CurrentM, 167=CapacityM, 168=PowerM, 169=RevolutionM, 170=TemperatureM 1, 171=TemperatureM 2 172=Voltage_min, 173=Current_max,
-		// 174=Revolution_max, 175=Temperature1_max, 176=Temperature2_max 177=Event M
-		// 178=Speed 179=Speed_max 180=PWM 181=Throttle 182=VoltageBEC 183=VoltageBEC_min 184=CurrentBEC 185=TemperatureBEC 186=TemperatureCap 
-		// 187=Timing(empty) 188=Temperature_aux 189=Gear 190=YGEGenExt 191=MotStatEscNr 192=misc ESC_15 193=VersionESC
+		// 181=VoltageM2, 182=CurrentM, 183=CapacityM, 184=PowerM, 185=RevolutionM, 186=TemperatureM 1, 187=TemperatureM 2 188=Voltage_min, 189=Current_max,
+		// 190=Revolution_max, 191=Temperature1_max, 192=Temperature2_max 193=Event M
+		// 194=Speed 195=Speed_max 196=PWM 197=Throttle 198=VoltageBEC 199=VoltageBEC_min 200=CurrentBEC 201=TemperatureBEC 202=TemperatureCap 
+		// 203=Timing(empty) 204=Temperature_aux 205=Gear 206=YGEGenExt 207=MotStatEscNr 208=misc ESC_15 209=VersionESC
 		//ESC4
-		// 194=VoltageM3, 195=CurrentM, 196=CapacityM, 197=PowerM, 198=RevolutionM, 199=TemperatureM 1, 200=TemperatureM 2 201=Voltage_min, 202=Current_max,
-		// 203=Revolution_max, 204=Temperature1_max, 205=Temperature2_max 206=Event M
-		// 207=Speed 208=Speed_max 209=PWM 210=Throttle 211=VoltageBEC 212=VoltageBEC_min 213=CurrentBEC 214=TemperatureBEC 215=TemperatureCap 
-		// 216=Timing(empty) 217=Temperature_aux 218=Gear 219=YGEGenExt 220=MotStatEscNr 221=misc ESC_15 222=VersionESC
+		// 210=VoltageM3, 211=CurrentM, 212=CapacityM, 213=PowerM, 214=RevolutionM, 215=TemperatureM 1, 216=TemperatureM 2 217=Voltage_min, 218=Current_max,
+		// 219=Revolution_max, 220=Temperature1_max, 221=Temperature2_max 222=Event M
+		// 223=Speed 224=Speed_max 225=PWM 226=Throttle 227=VoltageBEC 228=VoltageBEC_min 229=CurrentBEC 230=TemperatureBEC 231=TemperatureCap 
+		// 232=Timing(empty) 233=Temperature_aux 234=Gear 235=YGEGenExt 236=MotStatEscNr 237=misc ESC_15 238=VersionESC
 
-		// 223=Test 00 224=Test 01.. 235=Test 12
+		// 239=Test 00 240=Test 01.. 251=Test 12
 
 		//in 0=RXSQ, 1=Voltage, 2=Current, 3=Capacity, 4=Power, 5=Balance, 6=CellVoltage 1, 7=CellVoltage 2 .... 19=CellVoltage 14,
 		//in 20=Altitude, 21=Climb 1, 22=Climb 3, 23=Voltage 1, 24=Voltage 2, 25=Temperature 1, 26=Temperature 2 27=RPM 28=MotorTime 29=Speed 30=Event
@@ -522,9 +557,9 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 				HoTTlogReaderD.points[j + 15] = valuesVario[j + 8];
 			}
 
-			//out 223=Test 00 224=Test 01.. 235=Test 12
+			//out 239=Test 00 240=Test 01.. 251=Test 12
 			for (int j = 0; j < 13; j++) {
-				HoTTlogReaderD.points[j + 223] = valuesVario[j + 14];
+				HoTTlogReaderD.points[j + 239] = valuesVario[j + 14];
 			}
 		}
 		//in 0=RF_RXSQ, 1=Voltage, 2=Current, 3=Capacity, 4=Power, 5=Revolution, 6=Temperature1, 7=Temperature2
@@ -532,44 +567,45 @@ public class HoTTlogReaderD extends HoTTlogReader2 {
 		//in 14=Speed 15=Speed_max 16=PWM 17=Throttle 18=VoltageBEC 19=VoltageBEC_min 20=CurrentBEC 21=TemperatureBEC 22=TemperatureCap 
 		//in 23=Timing(empty) 24=Temperature_aux 25=Gear 26=YGEGenExt 27=MotStatEscNr 28=misc ESC_15 29=VersionESC
 		if (isEscData) {
-			//out 107=VoltageM, 108=CurrentM, 109=CapacityM, 110=PowerM, 111=RevolutionM, 112=TemperatureM 1, 113=TemperatureM 2 114=Voltage_min, 115=Current_max, 116=Revolution_max, 117=Temperature1_max, 118=Temperature2_max 119=Event M
-			//out 120=Speed 121=Speed_max 122=PWM 123=Throttle 124=VoltageBEC 125=VoltageBEC_min 125=CurrentBEC 127=TemperatureBEC 128=TemperatureCap 
-			//out 129=Timing(empty) 130=Temperature_aux 131=Gear 132=YGEGenExt 133=MotStatEscNr 134=misc ESC_15 135=VersionESC
+			// 123=VoltageM, 124=CurrentM, 125=CapacityM, 126=PowerM, 127=RevolutionM, 128=TemperatureM 1, 129=TemperatureM 2 130=Voltage_min, 131=Current_max,
+			// 132=Revolution_max, 133=Temperature1_max, 134=Temperature2_max 135=Event M
+			// 136=Speed 137=Speed_max 138=PWM 139=Throttle 140=VoltageBEC 141=VoltageBEC_max 142=CurrentBEC 143=TemperatureBEC 144=TemperatureCap 
+			// 145=Timing(empty) 146=Temperature_aux 147=Gear 148=YGEGenExt 149=MotStatEscNr 150=misc ESC_15 151=VersionESC
 			for (int j = 0; j < 29; j++) {
-				HoTTlogReaderD.points[j + 107] = valuesESC[j + 1];
+				HoTTlogReaderD.points[j + 123] = valuesESC[j + 1];
 			}
 		}
 		if (isEsc2Data) {
-			// 136=VoltageM, 137=CurrentM, 138=CapacityM, 139=PowerM, 140=RevolutionM, 141=TemperatureM 1, 142=TemperatureM 2 143=Voltage_min, 144=Current_max,
-			// 145=Revolution_max, 146=Temperature1_max, 147=Temperature2_max 148=Event M
-			// 149=Speed 150=Speed_max 151=PWM 152=Throttle 153=VoltageBEC 154=VoltageBEC_min 155=CurrentBEC 156=TemperatureBEC 157=TemperatureCap 
-			// 158=Timing(empty) 159=Temperature_aux 160=Gear 161=YGEGenExt 162=MotStatEscNr 163=misc ESC_15 164=VersionESC
+			// 152=VoltageM, 153=CurrentM, 154=CapacityM, 155=PowerM, 156=RevolutionM, 157=TemperatureM 1, 158=TemperatureM 2 159=Voltage_min, 160=Current_max,
+			// 161=Revolution_max, 162=Temperature1_max, 163=Temperature2_max 164=Event M
+			// 165=Speed 166=Speed_max 167=PWM 168=Throttle 169=VoltageBEC 170=VoltageBEC_min 171=CurrentBEC 172=TemperatureBEC 173=TemperatureCap 
+			// 174=Timing(empty) 175=Temperature_aux 176=Gear 177=YGEGenExt 178=MotStatEscNr 179=misc ESC_15 180=VersionESC
 			for (int j = 0; j < 29; j++) {
-				HoTTlogReaderD.points[j + 136] = valuesESC2[j + 1];
+				HoTTlogReaderD.points[j + 152] = valuesESC2[j + 1];
 			}
 		}
 		if (isEsc3Data) {
-			// 165=VoltageM2, 166=CurrentM, 167=CapacityM, 168=PowerM, 169=RevolutionM, 170=TemperatureM 1, 171=TemperatureM 2 172=Voltage_min, 173=Current_max,
-			// 174=Revolution_max, 175=Temperature1_max, 176=Temperature2_max 177=Event M
-			// 178=Speed 179=Speed_max 180=PWM 181=Throttle 182=VoltageBEC 183=VoltageBEC_min 184=CurrentBEC 185=TemperatureBEC 186=TemperatureCap 
-			// 187=Timing(empty) 188=Temperature_aux 189=Gear 190=YGEGenExt 191=MotStatEscNr 192=misc ESC_15 193=VersionESC
+			// 181=VoltageM2, 182=CurrentM, 183=CapacityM, 184=PowerM, 185=RevolutionM, 186=TemperatureM 1, 187=TemperatureM 2 188=Voltage_min, 189=Current_max,
+			// 190=Revolution_max, 191=Temperature1_max, 192=Temperature2_max 193=Event M
+			// 194=Speed 195=Speed_max 196=PWM 197=Throttle 198=VoltageBEC 199=VoltageBEC_min 200=CurrentBEC 201=TemperatureBEC 202=TemperatureCap 
+			// 203=Timing(empty) 204=Temperature_aux 205=Gear 206=YGEGenExt 207=MotStatEscNr 208=misc ESC_15 209=VersionESC
 			for (int j = 0; j < 29; j++) {
-				HoTTlogReaderD.points[j + 165] = valuesESC3[j + 1];
+				HoTTlogReaderD.points[j + 181] = valuesESC3[j + 1];
 			}
 		}
 		if (isEsc4Data) {
-			// 194=VoltageM3, 195=CurrentM, 196=CapacityM, 197=PowerM, 198=RevolutionM, 199=TemperatureM 1, 200=TemperatureM 2 201=Voltage_min, 202=Current_max,
-			// 203=Revolution_max, 204=Temperature1_max, 205=Temperature2_max 206=Event M
-			// 207=Speed 208=Speed_max 209=PWM 210=Throttle 211=VoltageBEC 212=VoltageBEC_min 213=CurrentBEC 214=TemperatureBEC 215=TemperatureCap 
-			// 216=Timing(empty) 217=Temperature_aux 218=Gear 219=YGEGenExt 220=MotStatEscNr 221=misc ESC_15 222=VersionESC
+			// 210=VoltageM3, 211=CurrentM, 212=CapacityM, 213=PowerM, 214=RevolutionM, 215=TemperatureM 1, 216=TemperatureM 2 217=Voltage_min, 218=Current_max,
+			// 219=Revolution_max, 220=Temperature1_max, 221=Temperature2_max 222=Event M
+			// 223=Speed 224=Speed_max 225=PWM 226=Throttle 227=VoltageBEC 228=VoltageBEC_min 229=CurrentBEC 230=TemperatureBEC 231=TemperatureCap 
+			// 232=Timing(empty) 233=Temperature_aux 234=Gear 235=YGEGenExt 236=MotStatEscNr 237=misc ESC_15 238=VersionESC
 			for (int j = 0; j < 29; j++) {
-				HoTTlogReaderD.points[j + 194] = valuesESC4[j + 1];
+				HoTTlogReaderD.points[j + 210] = valuesESC4[j + 1];
 			}
 		}
 
 		//add altitude and climb values from selected sensor
 		//log.log(Level.OFF, String.format("pickerParameters.altitudeClimbSensorSelection = %s", pickerParameters.altitudeClimbSensorSelection));
-		switch (Sensor.VALUES[HoTTbinReader.pickerParameters.altitudeClimbSensorSelection]) {
+		switch (Sensor.VALUES[HoTTlogReaderD.pickerParameters.altitudeClimbSensorSelection]) {
 		case VARIO:
 			//8=Altitude, 9=Climb 1, 10=Climb 3, 11=Climb 10
 			if (isVarioData) for (int j = 0; j < 4; j++) {
