@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with GNU DataExplorer.  If not, see <https://www.gnu.org/licenses/>.
 
-    Copyright (c) 2014,2015,2016,2017,2018,2019,2020,2021,2022,2023 Winfried Bruegmann
+    Copyright (c) 2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Winfried Bruegmann
 ****************************************************************************************/
 package gde.device.opentx;
 
@@ -355,7 +355,7 @@ public class CSVReaderWriter {
 							recordSet.setRecordSetDescription(recordSet.getRecordSetDescription() + line.replace('#', GDE.CHAR_BLANK) + GDE.LINE_SEPARATOR);
 						continue;
 					}
-					String[] dataStr = line.replace(", ", ",").split(" |"+separator); //replace(", ", ",") to allow GPS coords ..,48.474413, 11.477986,.. split(" |"+separator) to take ..,48.132850 11.720808,..
+					String[] dataStr = line.replace(",,", ",0.0 0.0,").replace(", ", ",").split(" |"+separator); //replace(", ", ",") to allow GPS coords ..,48.474413, 11.477986,.. split(" |"+separator) to take ..,48.132850 11.720808,..
 					String data = dataStr[0].trim();
 					int year = Integer.parseInt(data.substring(0, 4));
 					int month = Integer.parseInt(data.substring(5, 7));
